@@ -177,14 +177,18 @@ class API(ResourceAttributesMixin, object):
 
     def __init__(self, base_url=None, auth=None, format=None, append_slash=True, session=None, serializer=None):
         if serializer is None:
-            s = Serializer(default=format)
+            serializer = Serializer(default=format)
+
+        if session is None:
+            session = requests.session()
+            session.auth = auth
 
         self._store = {
             "base_url": base_url,
             "format": format if format is not None else "json",
             "append_slash": append_slash,
-            "session": requests.session(auth=auth) if session is None else session,
-            "serializer": s,
+            "session": session,
+            "serializer": serializer,
         }
 
         # Do some Checks for Required Values
